<?php

/**
 * Configuration page for Bing search.
 */
function winlivesearch_settings() {
  $form = array();
  $form['winlivesearch_limit'] = array(
    '#type' => 'textfield',
    '#title' => t('Number of results per page'),
    '#description' => t('Enter the number of results to display on each page.'),
    '#default_value' => variable_get('winlivesearch_limit', 15),
    '#maxlength' => 4,
    '#size' => 8,
  );
  $form['winlivesearch_appid'] = array(
    '#type' => 'textfield',
    '#title' => t('Bing App ID'),
    '#description' => t('Enter a valid <a href="http://www.bing.com/developers/createapp.aspx">Bing App ID</a>.'),
    '#default_value' => variable_get('winlivesearch_appid', ''),
    '#maxlength' => 60,
    '#size' => 60,
  );
  $form['winlivesearch_query'] = array(
    '#type' => 'textfield',
    '#title' => t('Appended query string'),
    '#description' => t('You may append an additional query string to the search query.  For example, restrict search results to two sites by entering "site:example.org OR site:example.com".  See <a href="http://msdn2.microsoft.com/en-us/library/aa905321.aspx">Working with Advanced Queries</a>.'),
    '#default_value' => variable_get('winlivesearch_query', ''),
    '#maxlength' => 640,
    '#size' => 80,
  );
  $form['winlivesearch_safesearch'] = array(
    '#type' => 'select',
    '#options' => array(
      'Off' => t('Off'),
      'Moderate' => t('Moderate'),
      'Strict' => t('Strict'),
    ),
    '#title' => t('Safe search'),
    '#description' => t('Choose a SafeSearch configuration.'),
    '#default_value' => variable_get('winlivesearch_safesearch', 'Strict'),
  );
  $form['winlivesearch_logo'] = array(
    '#type' => 'radios',
    '#options' => array(
      t('Disabled'),
      t('Enabled'),
    ),
    '#title' => t('Live Search logo'),
    '#description' => t('Display a Live Search logo on the search results page.'),
    '#default_value' => variable_get('winlivesearch_logo', 1),
  );
  $form['search_box'] = array(
    '#type' => 'fieldset',
    '#title' => t('Search boxes'),
    '#description' => t('Bing can be used as the default search engine for the block and/or theme search boxes.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['search_box']['winlivesearch_block'] = array(
    '#type' => 'radios',
    '#options' => array(
      t('Disabled'),
      t('Enabled'),
    ),
    '#title' => t('Bing search block'),
    '#description' => t('Use Bing as the default search engine for the block-based search box.'),
    '#default_value' => variable_get('winlivesearch_block', 1),
  );
  $form['search_box']['winlivesearch_theme'] = array(
    '#type' => 'radios',
    '#options' => array(
      t('Disabled'),
      t('Enabled'),
    ),
    '#title' => t('Bing search theme'),
    '#description' => t('Use Bing as the default search engine for the theme-based search box.'),
    '#default_value' => variable_get('winlivesearch_theme', 0),
  );
  $form['locale'] = array(
    '#type' => 'fieldset',
    '#title' => t('Locale settings'),
    '#description' => t('The configured locale code(s) must appear in the <a href="http://msdn.microsoft.com/en-us/library/dd251064.aspx">list of supported locale codes</a>.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['locale']['winlivesearch_use_locale'] = array(
    '#type' => 'radios',
    '#title' => t("Locale type"),
    '#description' => t('You may display search results in a static locale configured below or use the current Drupal locale as set by the locale module.'),
    '#options' => array('Static locale', 'Drupal locale'),
    '#default_value' => variable_get('winlivesearch_use_locale', 0),
  );
  $form['locale']['winlivesearch_locale'] = array(
    '#type' => 'textfield',
    '#title' => t('Static locale'),
    '#description' => t('Enter a static locale code, e.g. <em>en-US</em>.'),
    '#default_value' => variable_get('winlivesearch_locale', 'en-US'),
    '#maxlength' => 5,
    '#size' => 10,
  );
  $form['advanced'] = array(
    '#type' => 'fieldset',
    '#title' => t('Advanced settings'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['advanced']['winlivesearch_source'] = array(
    '#type' => 'textfield',
    '#title' => t('Search source'),
    '#description' => 'Enter a <a href="http://msdn.microsoft.com/en-us/library/dd250895.aspx">supported source</a>.',
    '#default_value' => variable_get('winlivesearch_source', 'Web'),
  );
  return system_settings_form($form);
}
